@@ -63,6 +63,88 @@ def _get_coordinates(varfont, glyphname):
     )
 
 
+class InstantiateCFF2Test(object):
+    @pytest.mark.parametrize(
+        "location, expected",
+        [
+            (
+                {},
+                [
+                    44,
+                    256,
+                    6,
+                    -29,
+                    2,
+                    "blend",
+                    "rmoveto",
+                    239,
+                    35,
+                    -239,
+                    44,
+                    90,
+                    -44,
+                    3,
+                    "blend",
+                    "hlineto",
+                ],
+            ),
+            ({"wght": 0}, [44, 256, "rmoveto", 239, 35, -239, "hlineto"]),
+            ({"wght": 0.5}, [47, 242, "rmoveto", 261, 80, -261, "hlineto"]),
+            ({"wght": 1}, [50, 227, "rmoveto", 283, 125, -283, "hlineto"]),
+        ],
+    )
+    def test_pin_and_drop_axis(self, varfont, location, expected):
+
+        varfont = ttLib.TTFont()
+        varfont.importXML(os.path.join(TESTDATA, "CFF2Instancer-VF-1.ttx"))
+
+        location = instancer.NormalizedAxisLimits(location)
+
+        instancer.instantiateCFF2(varfont, location)
+        instancer.instantiateHVAR(varfont, location)
+
+        program = varfont["CFF2"].cff.topDictIndex[0].CharStrings.values()[1].program
+        assert program == expected
+
+    @pytest.mark.parametrize(
+        "source_ttx, expected_ttx",
+        [
+            ("CFF2Instancer-VF-1.ttx", "CFF2Instancer-VF-1-instance-400.ttx"),
+            ("CFF2Instancer-VF-2.ttx", "CFF2Instancer-VF-2-instance-400.ttx"),
+            ("CFF2Instancer-VF-3.ttx", "CFF2Instancer-VF-3-instance-400.ttx"),
+        ],
+    )
+    def test_full_instance(self, varfont, source_ttx, expected_ttx):
+        varfont = ttLib.TTFont()
+        varfont.importXML(os.path.join(TESTDATA, source_ttx))
+        s = BytesIO()
+        varfont.save(s)
+        s.seek(0)
+        varfont = ttLib.TTFont(s)
+
+        instance = instancer.instantiateVariableFont(varfont, {"wght": 400})
+        s = BytesIO()
+        instance.save(s)
+        s.seek(0)
+        instance = ttLib.TTFont(s)
+
+        s = StringIO()
+        instance.saveXML(s)
+        actual = stripVariableItemsFromTTX(s.getvalue())
+
+        expected = ttLib.TTFont()
+        expected.importXML(os.path.join(TESTDATA, "test_results", expected_ttx))
+        s = BytesIO()
+        expected.save(s)
+        s.seek(0)
+        expected = ttLib.TTFont(s)
+        s = StringIO()
+        expected.saveXML(s)
+        expected = stripVariableItemsFromTTX(s.getvalue())
+
+        assert actual == expected
+
+
 class InstantiateGvarTest(object):
     @pytest.mark.parametrize("glyph_name", ["hyphen"])
     @pytest.mark.parametrize(
@@ -1617,23 +1699,33 @@ class InstantiateVariableFontTest(object):
 
     def test_varComposite(self):
         input_path = os.path.join(
-            TESTDATA, "..", "..", "..", "ttLib", "data", "varc-ac00-ac01.ttf"
+            TESTDATA, "..", "..", "..", "ttLib", "data", "varc-6868.ttf"
         )
         varfont = ttLib.TTFont(input_path)
 
         location = {"wght": 600}
 
-        instance = instancer.instantiateVariableFont(
-            varfont,
-            location,
-        )
+        # We currently do not allow this either; although in theory
+        # it should be possible.
+        with pytest.raises(
+            NotImplementedError,
+            match="is not supported.",
+        ):
+            instance = instancer.instantiateVariableFont(
+                varfont,
+                location,
+            )
 
         location = {"0000": 0.5}
 
-        instance = instancer.instantiateVariableFont(
-            varfont,
-            location,
-        )
+        with pytest.raises(
+            NotImplementedError,
+            match="is not supported.",
+        ):
+            instance = instancer.instantiateVariableFont(
+                varfont,
+                location,
+            )
 
 
 def _conditionSetAsDict(conditionSet, axisOrder):
@@ -2015,6 +2107,19 @@ class LimitTupleVariationAxisRangesTest:
                 0.5,
                 [TupleVariation({"wght": (1.0, 1.0, 1.0)}, [100, 100])],
             ),
+            # test case from https://github.com/fonttools/fonttools/issues/3453
+            (
+                TupleVariation(
+                    {
+                        "wght": (0.0, 1.0, 1.0),
+                        "ital": (0.0, 0.0, 1.0),  # no-op axis gets dropped
+                    },
+                    [100, 100],
+                ),
+                "ital",
+                0.0,
+                [TupleVariation({"wght": (0.0, 1.0, 1.0)}, [100, 100])],
+            ),
         ],
     )
     def test_positive_var(self, var, axisTag, newMax, expected):
